# p1 [![Português](images/BR.png)](README.pt-BR.md) [![English](images/US.png)](README.md)

p1 é um pacote com ferramentas para o apoio às disciplinas de
Programação 1 da Computação@UFCG.

## Instalação

```
pip3 install --user p1
```
